@@ -306,6 +306,10 @@ def download_prefix(dataset_name: str, namespace: str, prefix: str, destination:
             _log(f"Skipping {len(exist_objs)} files out of {len(downloads)} that already exist.")
 
         force_quit = False
+
+        # Reset the boto3 client in the object store before pickling occurs.
+        ds.namespace.object_store.reset_client()
+
         if num_to_download > 0:
             _log(f"Downloading {num_to_download} files.")
             # Create workers
@@ -533,7 +537,7 @@ def _download_worker(work_queue: Queue, status_queue: Queue, dataset: Dataset,
     """
     # Reset the boto3 client in the object store that was passed in. This is important to do before the client is
     # used across processes as this is not a safe operation.
-    dataset.namespace.object_store.reset_client(dataset.namespace.name)
+    dataset.namespace.object_store.reset_client()
 
     while True:
         try:
